@@ -325,7 +325,7 @@ const BgraphBipartFmParam * const paraptr)        /*+ Method parameters +*/
 
   if (typeval == BGRAPHBIPARTFMTYPEALL)           /* Take maximum space so that hashmax will fit */
     hashnbr = grafptr->s.vertnbr * 4;
-    
+
   for (hashsiz = 256; hashsiz < hashnbr; hashsiz <<= 1) ; /* Get upper power of two */
   hashmsk = hashsiz - 1;
   hashmax = hashsiz >> 2;
@@ -333,7 +333,7 @@ const BgraphBipartFmParam * const paraptr)        /*+ Method parameters +*/
   if (bgraphBipartFmTablInit (&tabldat) != 0) {
     errorPrint ("bgraphBipartFm: internal error (1)"); /* Unable to do proper initialization */
     bgraphBipartFmTablExit (&tabldat);
-    return (1);  
+    return (1);
   }
 
   tablptr = &tabldat;
@@ -585,7 +585,7 @@ const BgraphBipartFmParam * const paraptr)        /*+ Method parameters +*/
             }
             break;
           }
-          if (hashtab[hashnum].vertnum == ~0) {   /* If hash slot empty */
+          if (hashtab[hashnum].vertnum == ~0) {   /* If hash slot empty                       */
             Gnum                commgain;         /* Communication gain of current vertex     */
             Gnum                commgainold;      /* Old communication gain of current vertex */
             Gnum                veloval;
@@ -675,7 +675,7 @@ const BgraphBipartFmParam * const paraptr)        /*+ Method parameters +*/
           compload0dltbst = compload0dlt;         /* Forget backtracking */
           commgainextnbst = commgainextn;
           swapvalbst      = swapval;
-          savenbr         = 0;                   
+          savenbr         = 0;
           mswpnum ++;
         }
       }
@@ -1001,6 +1001,13 @@ const Gnum                                  commgainextn)
   Gnum                  commloadextndlttmp;
   Gnum                  commgainextntmp;
 
+  const Gnum * restrict const verttax = grafptr->s.verttax; /* Fast accesses */
+  const Gnum * restrict const vendtax = grafptr->s.vendtax;
+  const Gnum * restrict const velotax = grafptr->s.velotax;
+  const Gnum * restrict const edgetax = grafptr->s.edgetax;
+  const Gnum * restrict const edlotax = grafptr->s.edlotax;
+  const Gnum * restrict const veextax = grafptr->veextax;
+
   domndist           = grafptr->domndist;
   compload0tmp       = (swapval == 0) ? grafptr->compload0 : (grafptr->s.velosum - grafptr->compload0);
   commloaddlttmp     = 0;                         /* No difference yet */
