@@ -1,4 +1,4 @@
-/* Copyright 2012,2015,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2012,2015,2018,2020 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -40,7 +40,7 @@
 /**                matching routines.                      **/
 /**                                                        **/
 /**   DATES      : # Version 6.0  : from : 02 oct 2012     **/
-/**                                 to     07 jun 2018     **/
+/**                                 to     21 feb 2020     **/
 /**                                                        **/
 /************************************************************/
 
@@ -81,10 +81,10 @@
 */
 
 #ifdef GRAPH_MATCH
-GRAPHMATCHFUNCDECL (Seq);
-GRAPHMATCHFUNCDECL (ThrBeg);
-GRAPHMATCHFUNCDECL (ThrMid);
-GRAPHMATCHFUNCDECL (ThrEnd);
+GRAPHMATCHFUNCDECL (Seq)
+GRAPHMATCHFUNCDECL (ThrBeg)
+GRAPHMATCHFUNCDECL (ThrMid)
+GRAPHMATCHFUNCDECL (ThrEnd)
 #endif /* GRAPH_MATCH */
 
 void                        graphMatchNone      (GraphCoarsenData *);
