@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010-2012,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010-2012,2014,2018,2020 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -50,7 +50,7 @@
 /**                # Version 5.1  : from : 28 sep 2008     **/
 /**                                 to     31 aug 2011     **/
 /**                # Version 6.0  : from : 03 mar 2011     **/
-/**                                 to     26 feb 2018     **/
+/**                                 to     27 aug 2020     **/
 /**                                                        **/
 /************************************************************/
 
@@ -97,7 +97,8 @@ const Gnum * restrict const     vmlotax)          /*+ Vertex migration cost arra
   ArchDom                   domndat;              /* First, largest domain */
 
 #ifdef SCOTCH_DEBUG_KGRAPH2
-  if ((crloval < 1) || (cmloval < 0)) {
+  if (((parotax != NULL) && (crloval < 1)) ||
+      ((vmlotax != NULL) && (cmloval < 0))) {
     errorPrint ("kgraphInit: invalid parameters");
     return     (1);
   }
