@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010,2012-2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2012-2014,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -50,7 +50,7 @@
 /**                # Version 5.1  : from : 30 oct 2007     **/
 /**                                 to     14 aug 2010     **/
 /**                # Version 6.0  : from : 08 jan 2012     **/
-/**                                 to     10 jul 2018     **/
+/**                                 to     29 sep 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -170,7 +170,7 @@ const SCOTCH_Graph * const    grafptr,            /*+ Graph to order   +*/
 const SCOTCH_Ordering * const ordeptr,            /*+ Ordering to save +*/
 FILE * const                  stream)             /*+ Output stream    +*/
 {
-  return (orderSave (&((LibOrder *) ordeptr)->o, ((Graph *) grafptr)->vlbltax + ((Graph *) grafptr)->baseval, stream));
+  return (orderSave (&((LibOrder *) ordeptr)->o, ((Graph *) grafptr)->vlbltax, stream));
 }
 
 /*+ This routine saves to the given stream
@@ -187,7 +187,7 @@ const SCOTCH_Graph * const    grafptr,            /*+ Graph to order   +*/
 const SCOTCH_Ordering * const ordeptr,            /*+ Ordering to save +*/
 FILE * const                  stream)             /*+ Output stream    +*/
 {
-  return (orderSaveMap (&((LibOrder *) ordeptr)->o, ((Graph *) grafptr)->vlbltax + ((Graph *) grafptr)->baseval, stream));
+  return (orderSaveMap (&((LibOrder *) ordeptr)->o, ((Graph *) grafptr)->vlbltax, stream));
 }
 
 /*+ This routine saves to the given stream
@@ -204,7 +204,7 @@ const SCOTCH_Graph * const    grafptr,            /*+ Graph to order   +*/
 const SCOTCH_Ordering * const ordeptr,            /*+ Ordering to save +*/
 FILE * const                  stream)             /*+ Output stream    +*/
 {
-  return (orderSaveTree (&((LibOrder *) ordeptr)->o, ((Graph *) grafptr)->vlbltax + ((Graph *) grafptr)->baseval, stream));
+  return (orderSaveTree (&((LibOrder *) ordeptr)->o, ((Graph *) grafptr)->vlbltax, stream));
 }
 
 /*+ This routine computes an ordering
@@ -265,7 +265,7 @@ SCOTCH_Strat * const        stratptr)             /*+ Ordering strategy
   }
 #endif /* SCOTCH_DEBUG_LIBRARY2 */
 
-  if (listnbr == 0) {                             /* If empty list, return identity peremutation */
+  if (listnbr == 0) {                             /* If empty list, return identity permutation */
     intAscn (libordeptr->o.peritab, srcgrafptr->vertnbr, srcgrafptr->baseval);
     return  (0);
   }
@@ -337,7 +337,7 @@ SCOTCH_Strat * const        stratptr)             /*+ Ordering strategy
         peritax[halonum --] = vertnum;
     }
 #ifdef SCOTCH_DEBUG_LIBRARY2
-    if (halonum != (listnbr + srcgrafptr->baseval - 1)) { 
+    if (halonum != (listnbr + srcgrafptr->baseval - 1)) {
       errorPrint (STRINGIFY (SCOTCH_graphOrderComputeList) ": internal error");
       return     (1);
     }
