@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2020 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -45,6 +45,8 @@
 /**                                 to     24 mar 2008     **/
 /**                # Version 5.1  : from : 09 nov 2008     **/
 /**                                 to     09 nov 2008     **/
+/**                # Version 6.0  : from : 23 jan 2020     **/
+/**                                 to     06 feb 2020     **/
 /**                                                        **/
 /************************************************************/
 
@@ -104,13 +106,13 @@ const VmeshSeparateGgParam * restrict const paraptr) /*+ Method parameters    +*
     return    (0);
   }
 
-  velssiz = (meshptr->m.vnlotax == NULL) ? 0 : meshptr->m.velmnbr; /*  Compute size of vetex load sum array */
-  if (((tablptr = gainTablInit (GAINMAX, VMESHSEPAGGSUBBITS)) == NULL) || /* Use logarithmic array only     */
+  velssiz = (meshptr->m.vnlotax == NULL) ? 0 : meshptr->m.velmnbr; /*  Compute size of vertex load sum array */
+  if (((tablptr = gainTablInit (GAINMAX, VMESHSEPAGGSUBBITS)) == NULL) || /* Use logarithmic array only      */
       ((vexxtab = (byte *) memAllocGroup ((void **) (void *)
-                             &velxtax, (size_t) (meshptr->m.velmnbr * sizeof (VmeshSeparateGgElem)),
-                             &vnoxtax, (size_t) (meshptr->m.vnodnbr * sizeof (VmeshSeparateGgNode)),
-                             &velitax, (size_t) (meshptr->m.velmnbr * sizeof (Gnum)),
-                             &velstax, (size_t) (velssiz            * sizeof (Gnum)), NULL)) == NULL)) { /* Indicates end of group allocated array */
+                                          &velxtax, (size_t) (meshptr->m.velmnbr * sizeof (VmeshSeparateGgElem)),
+                                          &vnoxtax, (size_t) (meshptr->m.vnodnbr * sizeof (VmeshSeparateGgNode)),
+                                          &velitax, (size_t) (meshptr->m.velmnbr * sizeof (Gnum)),
+                                          &velstax, (size_t) (velssiz            * sizeof (Gnum)), NULL)) == NULL)) {
     if (tablptr != NULL)
       gainTablExit (tablptr);
     errorPrint ("vmeshSeparateGg: out of memory (1)");
@@ -167,7 +169,8 @@ const VmeshSeparateGgParam * restrict const paraptr) /*+ Method parameters    +*
 
   permtab = NULL;                                 /* Do not allocate permutation array yet */
   for (passnum = 0; passnum < paraptr->passnbr; passnum ++) { /* For all passes            */
-    VmeshSeparateGgElem *             velxptr;    /* Pointer to selected element           */
+    VmeshSeparateGgElem * velxptr;                /* Pointer to selected element           */
+    Gnum                  velmnum;
 
     memSet (vexxtab, 0, vexxsiz);                 /* All vertices to part 0      */
     gainTablFree (tablptr);                       /* Reset gain table            */
@@ -176,7 +179,11 @@ const VmeshSeparateGgParam * restrict const paraptr) /*+ Method parameters    +*
     ncmpload2   = 0;                              /* Reset separation parameters */
     ncmploaddlt = meshptr->m.vnlosum;
 
-    velxptr = (VmeshSeparateGgElem *) vexxtab + intRandVal (meshptr->m.velmnbr); /* Randomly select first root element vertex */
+    velmnum = meshptr->m.velmbas + intRandVal (meshptr->m.velmnbr); /* Randomly select first root element vertex              */
+    if (meshptr->m.verttax[velmnum] == meshptr->m.vendtax[velmnum]) /* If picked an isolated element, search for another root */
+      goto next;
+
+    velxptr = velxtax + velmnum;                  /* Set root pointer to root element */
 
     do {                                          /* Loop on root element vertices        */
       Gnum                velmnum;                /* Number of current element to process */
@@ -349,34 +356,39 @@ const VmeshSeparateGgParam * restrict const paraptr) /*+ Method parameters    +*
 #endif /* SCOTCH_DEBUG_VMESH3 */
       } while ((velxptr = (VmeshSeparateGgElem *) gainTablFrst (tablptr)) != NULL);
 
-      if (permptr == NULL) {                      /* If element permutation not yet built   */
-        if (permtab == NULL) {                    /* If permutation array not yet allocated */
+next:                                             /* Select next root element systematically */
+      if (permptr == NULL) {                      /* If element permutation not yet built    */
+        if (permtab == NULL) {                    /* If permutation array not yet allocated  */
           if ((permtab = (Gnum *) memAlloc (meshptr->m.velmnbr * sizeof (Gnum))) == NULL) {
             errorPrint   ("vmeshSeparateGg: out of memory (2)");
             memFree      (vexxtab);
             gainTablExit (tablptr);
             return (1);
           }
-          intAscn (permtab, meshptr->m.velmnbr, meshptr->m.baseval); /* Initialize permutation array */
+          intAscn (permtab, meshptr->m.velmnbr, meshptr->m.velmbas); /* Initialize permutation array with based element indices */
         }
         intPerm (permtab, meshptr->m.velmnbr);    /* Build random permutation          */
         permptr = permtab;                        /* Start at beginning of permutation */
       }
-      for ( ; permptr < permtab + meshptr->m.velmnbr; permptr ++) { /* Find next root vertex */
+      for ( ; permptr < permtab + meshptr->m.velmnbr; ) { /* Find next root vertex */
+        Gnum                velmnum;
+
+        velmnum = *(permptr ++);                  /* Pick candidate root element and skip to next one */
 #ifdef SCOTCH_DEBUG_VMESH2
-        if (velxtax[*permptr].gainlink.next >= VMESHSEPAGGSTATEPART2) {
+        if (velxtax[velmnum].gainlink.next >= VMESHSEPAGGSTATEPART2) {
           errorPrint ("vmeshSeparateGg: internal error (7)");
           return     (1);
         }
 #endif /* SCOTCH_DEBUG_VMESH2 */
-        if (velxtax[*permptr].gainlink.next == VMESHSEPAGGSTATEPART0) {
-          velxptr = velxtax + (*permptr ++);
+        if ((velxtax[velmnum].gainlink.next == VMESHSEPAGGSTATEPART0) && /* If still in part 0 */
+            (meshptr->m.vendtax[velmnum] > meshptr->m.verttax[velmnum])) { /* And not isolated */
+          velxptr = velxtax + velmnum;            /* Select it as next root element            */
           break;
         }
       }
     } while (velxptr != NULL);
 
-    if ((passnum == 0) ||                         /* If it is the first try         */
+    if ((passnum == 0) ||                         /* If it is the first try        */
         ( (meshptr->ncmpload[2] >  ncmpload2) ||  /* Or if better solution reached */
          ((meshptr->ncmpload[2] == ncmpload2) &&
           (abs (meshptr->ncmploaddlt) > abs (ncmploaddlt))))) {
